==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/ApplicationLayoutRule.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ApplicationLayoutRuleCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ApplicationLayoutRule
 */
@JsonPropertyOrder({ ApplicationLayoutRule.JSON_PROPERTY_EFFECT, ApplicationLayoutRule.JSON_PROPERTY_CONDITION })
@JsonTypeName("ApplicationLayout_rule")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ApplicationLayoutRule implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EFFECT = "effect";
    private String effect;

    public static final String JSON_PROPERTY_CONDITION = "condition";
    private ApplicationLayoutRuleCondition condition;

    public ApplicationLayoutRule() {
    }

    public ApplicationLayoutRule effect(String effect) {

        this.effect = effect;
        return this;
    }

    /**
     * Get effect
     *
     * @return effect
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EFFECT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEffect() {
        return effect;
    }

    @JsonProperty(JSON_PROPERTY_EFFECT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEffect(String effect) {
        this.effect = effect;
    }

    public ApplicationLayoutRule condition(ApplicationLayoutRuleCondition condition) {

        this.condition = condition;
        return this;
    }

    /**
     * Get condition
     *
     * @return condition
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONDITION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ApplicationLayoutRuleCondition getCondition() {
        return condition;
    }

    @JsonProperty(JSON_PROPERTY_CONDITION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCondition(ApplicationLayoutRuleCondition condition) {
        this.condition = condition;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ApplicationLayoutRule applicationLayoutRule = (ApplicationLayoutRule) o;
        return Objects.equals(this.effect, applicationLayoutRule.effect)
                && Objects.equals(this.condition, applicationLayoutRule.condition);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(effect, condition);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationLayoutRule {\n");
        sb.append("    effect: ").append(toIndentedString(effect)).append("\n");
        sb.append("    condition: ").append(toIndentedString(condition)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/ApplicationLayoutRule.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ApplicationLayoutRuleCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ApplicationLayoutRule
 */
@JsonPropertyOrder({ ApplicationLayoutRule.JSON_PROPERTY_EFFECT, ApplicationLayoutRule.JSON_PROPERTY_CONDITION })
@JsonTypeName("ApplicationLayout_rule")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ApplicationLayoutRule implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EFFECT = "effect";
    private String effect;

    public static final String JSON_PROPERTY_CONDITION = "condition";
    private ApplicationLayoutRuleCondition condition;

    public ApplicationLayoutRule() {
    }

    public ApplicationLayoutRule effect(String effect) {

        this.effect = effect;
        return this;
    }

    /**
     * Get effect
     *
     * @return effect
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EFFECT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEffect() {
        return effect;
    }

    @JsonProperty(JSON_PROPERTY_EFFECT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEffect(String effect) {
        this.effect = effect;
    }

    public ApplicationLayoutRule condition(ApplicationLayoutRuleCondition condition) {

        this.condition = condition;
        return this;
    }

    /**
     * Get condition
     *
     * @return condition
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONDITION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ApplicationLayoutRuleCondition getCondition() {
        return condition;
    }

    @JsonProperty(JSON_PROPERTY_CONDITION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCondition(ApplicationLayoutRuleCondition condition) {
        this.condition = condition;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ApplicationLayoutRule applicationLayoutRule = (ApplicationLayoutRule) o;
        return Objects.equals(this.effect, applicationLayoutRule.effect)
                && Objects.equals(this.condition, applicationLayoutRule.condition);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(effect, condition);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationLayoutRule {\n");
        sb.append("    effect: ").append(toIndentedString(effect)).append("\n");
        sb.append("    condition: ").append(toIndentedString(condition)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
